==> ZenTaoPMS.max2.0.rc1.php7.1.zip: zentaopms/module/auditplan/lang/zh-tw.php <==
<?php
$lang->auditplan->create        = '新建計劃';
$lang->auditplan->edit          = '編輯';
$lang->auditplan->browse        = '瀏覽列表';

$lang->auditplan->browseAction = '計劃列表';
$lang->auditplan->editAction   = '編輯計劃';

$lang->auditplan->id            = '編號';
$lang->auditplan->item          = '檢查項';
$lang->auditplan->name          = '名稱';
$lang->auditplan->day           = '天';
$lang->auditplan->week          = '周';
$lang->auditplan->month         = '月';
$lang->auditplan->date          = '檢查時間';
$lang->auditplan->cycle         = '周期設置';
$lang->auditplan->interval      = '間隔';
$lang->auditplan->deadline      = '過期時間';
$lang->auditplan->comment       = '備註';
$lang->auditplan->content       = '檢查內容';
$lang->auditplan->check         = '檢查';
$lang->auditplan->batchCheck    = '批量檢查';
$lang->auditplan->checkedBy     = '檢查人';
$lang->auditplan->result        = '檢查結果';
$lang->auditplan->noData        = '暫無數據';
$lang->auditplan->noCheckList   = '暫無對應檢查單，請到組織創建';
$lang->auditplan->common        = '檢查計劃';
$lang->auditplan->saveDraft     = '保存草稿';
$lang->auditplan->batchCreate   = '批量新建';
$lang->auditplan->nc            = '不符合項';
$lang->auditplan->process       = '所屬過程';
$lang->auditplan->processType   = '過程分類';
$lang->auditplan->objectType    = '對象類型';
$lang->auditplan->objectID      = '檢查對象';
$lang->auditplan->activity      = '活動';
$lang->auditplan->zoutput       = '文檔';
$lang->auditplan->status        = '狀態';
$lang->auditplan->severity      = '嚴重程度';
$lang->auditplan->createdBy     = '由誰創建';
$lang->auditplan->createdDate   = '創建時間';
$lang->auditplan->createNc      = '創建不符合項';
$lang->auditplan->desc          = '描述';
$lang->auditplan->assignedTo    = '指派給';
$lang->auditplan->checkDate     = '計劃檢查時間';
$lang->auditplan->realCheckDate = '實際檢查時間';

$lang->auditplan->commentEmpty  = '當結果為否時，備註不能為空！';
$lang->auditplan->confirmDelete = '您確認刪除該審核計劃嗎？';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = '所有';
$lang->auditplan->statusList['wait']     = '待檢查';
$lang->auditplan->statusList['checked']  = '已檢查';
$lang->auditplan->statusList['checking'] = '檢查中';
$lang->auditplan->statusList['assignTo'] = '指派給我';
$lang->auditplan->statusList['delay']    = '已延期';
$lang->auditplan->statusList['today']    = '今日檢查';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = '昨日檢查';
$lang->auditplan->moreStatusList['lastMonth'] = '上月檢查';
$lang->auditplan->moreStatusList['month']     = '本月檢查';
$lang->auditplan->moreStatusList['nextMonth'] = '下月檢查';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = '是';
$lang->auditplan->resultList['fail']    = '否';
$lang->auditplan->resultList['useless'] = '不適用';

==> ZenTaoPMS.max2.2.php7.1.zip: zentaopms/module/auditplan/lang/zh-tw.php <==
<?php
$lang->auditplan->create        = '新建計劃';
$lang->auditplan->edit          = '編輯';
$lang->auditplan->browse        = '瀏覽列表';

$lang->auditplan->browseAction = '計劃列表';
$lang->auditplan->editAction   = '編輯計劃';

$lang->auditplan->id            = '編號';
$lang->auditplan->item          = '檢查項';
$lang->auditplan->name          = '名稱';
$lang->auditplan->day           = '天';
$lang->auditplan->week          = '周';
$lang->auditplan->month         = '月';
$lang->auditplan->date          = '檢查時間';
$lang->auditplan->cycle         = '周期設置';
$lang->auditplan->interval      = '間隔';
$lang->auditplan->deadline      = '過期時間';
$lang->auditplan->comment       = '備註';
$lang->auditplan->content       = '檢查內容';
$lang->auditplan->check         = '檢查';
$lang->auditplan->batchCheck    = '批量檢查';
$lang->auditplan->checkedBy     = '檢查人';
$lang->auditplan->result        = '檢查結果';
$lang->auditplan->noData        = '暫無數據';
$lang->auditplan->noCheckList   = '暫無對應檢查單，請到後台創建';
$lang->auditplan->common        = '檢查計劃';
$lang->auditplan->saveDraft     = '保存草稿';
$lang->auditplan->batchCreate   = '批量新建';
$lang->auditplan->nc            = '不符合項';
$lang->auditplan->process       = '所屬過程';
$lang->auditplan->processType   = '過程分類';
$lang->auditplan->objectType    = '對象類型';
$lang->auditplan->objectID      = '檢查對象';
$lang->auditplan->activity      = '活動';
$lang->auditplan->zoutput       = '文檔';
$lang->auditplan->status        = '狀態';
$lang->auditplan->severity      = '嚴重程度';
$lang->auditplan->createdBy     = '由誰創建';
$lang->auditplan->createdDate   = '創建時間';
$lang->auditplan->createNc      = '創建不符合項';
$lang->auditplan->desc          = '描述';
$lang->auditplan->assignedTo    = '指派給';
$lang->auditplan->checkDate     = '計劃檢查時間';
$lang->auditplan->realCheckDate = '實際檢查時間';

$lang->auditplan->commentEmpty  = '當結果為否時，備註不能為空！';
$lang->auditplan->confirmDelete = '您確認刪除該審核計劃嗎？';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = '所有';
$lang->auditplan->statusList['wait']     = '待檢查';
$lang->auditplan->statusList['checked']  = '已檢查';
$lang->auditplan->statusList['checking'] = '檢查中';
$lang->auditplan->statusList['assignTo'] = '指派給我';
$lang->auditplan->statusList['delay']    = '已延期';
$lang->auditplan->statusList['today']    = '今日檢查';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = '昨日檢查';
$lang->auditplan->moreStatusList['lastMonth'] = '上月檢查';
$lang->auditplan->moreStatusList['month']     = '本月檢查';
$lang->auditplan->moreStatusList['nextMonth'] = '下月檢查';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = '是';
$lang->auditplan->resultList['fail']    = '否';
$lang->auditplan->resultList['useless'] = '不適用';
